% Speed controlled system with proportional gain only  k
% Torsional resonance, elastic shaft coupling. 

%--------------------------------------------------------------------
% Parameter setting

JM= 0.0007;     % motor inertia
JL= 0.0007;     % load inertia
KK = 317;       % shaft stiffness
KV = 0.12;      % viscous friction
JEQ = JM + JL;  

WP = sqrt(KK*(JM+JL)/JM/JL);    % torsional resonance poles, zeros, damping 
WZ = sqrt(KK/JL);
XP = sqrt(KV*KV*(JM+JL)/4/JM/JL/KK);
XZ = sqrt(KV*KV/4/JL/KK);

numr = [1  2*XZ*WZ  WZ*WZ];     % transfer function of the torsional resonance
denr = [1  2*XP*WP  WP*WP];
numj = WP*WP/WZ/WZ; 

denj = [ JEQ  0];               % transfer function 1/Js

WHF = 2000;                     % assumed double pole at higher frequencies, 2000 rad/s
denhf = [1  2*WHF WHF*WHF];     % simulates measurement delays and actuator delays
numhf = WHF*WHF; 

close all; 

%--------------------------------------------------------------------
% Session 1, evans Root Locus of the system without any compensation. 

[num,den]=series(numr,denr,numhf,denhf);
[num,den]=series(num,den,numj,denj);
numold = num; denold = den; 
ss1 = tf(num,den); 

rlocus(num,den); axis([-2500 500 -3500 3500]); grid; 
title('no compensation at all')

k = 3.14895, roots(den+k*num)      %Maximum applicable gain in this case

pause

%--------------------------------------------------------------------
% Session 2, evans Root Locus of the system with notch zeros 
%            compensating the torsional poles. Notch poles
%            are designed to have damping of XP = 1

WNF = sqrt(KK*(JM+JL)/JM/JL);     % Notch filter design
XZNF = XP; 
XPNF = 1; 

numnf = [1  2*XZNF*WNF  WNF*WNF];
dennf = [1  2*XPNF*WNF  WNF*WNF];

[numc,denc]=series(numold,denold,numnf,dennf);

rlocus(numc,denc); grid; 
title('Notch filter compensation')
axis([-2500 500 -3500 3500]); 

k = 10, roots(denc+k*numc)      %Maximum applicable gain in this case

pause


%--------------------------------------------------------------------
% Session 3, evans Root Locus of the system with notch zeros 
%            compensating the torsional poles. Notch poles
%            are designed to have damping of XP = 1
%            NOTCH ZEROS HAVE AN ERROR OF 0.1 RAD

WNF = sqrt(KK*(JM+JL)/JM/JL);     % Notch filter design
XZNF = cos(acos(XP)-0.1);        % An error of 0.1 rad
XPNF = 1; 

numnf = [1  2*XZNF*WNF  WNF*WNF];
dennf = [1  2*XPNF*WNF  WNF*WNF];

[numc,denc]=series(numold,denold,numnf,dennf);

rlocus(numc,denc); grid; 
title('Notch filter compensation, error of 0.1 rad')
axis([-2500 500 -3500 3500]); 

k = 9.08, roots(denc+k*numc)      %Maximum applicable gain in this case




